pub unsafe fn trick_init<P: Printer + Send + Sync + 'static>(
logger: &Logger<P>,
) -> Result<(), SetLoggerError>Expand description
Performs init by tricking compiler into beliving that &Logger is static.
This is unsafe and it is up to you to ensure that reference will live longer that any attempts to access it