macro_rules! d_println {
($logger:expr, $($arg:tt)+) => { ... };
}Expand description
Deubg print macro that uses Printers to write formatted output with newline
It is defined to empty macro unless debug_assertions is enabled
macro_rules! d_println {
($logger:expr, $($arg:tt)+) => { ... };
}Deubg print macro that uses Printers to write formatted output with newline
It is defined to empty macro unless debug_assertions is enabled