pub fn init<P: Printer + Send + Sync>(
logger: &'static Logger<P>,
) -> Result<(), SetLoggerError>Expand description
Initialize logging facilities.
Currently lacks a nice way to set global logger so user must himself guarantee static lifetime
Atomic availability notes
On some targets, only limited set of atomic ops are available. In this case, this function initializes logger only once